@@ -1,5 +1,5 @@
 <?php
-require_once('../wp-includes/wp-l10n.php');
+require_once('admin.php');
 
 $title = 'Upload Image or File';
 
@@ -11,6 +11,9 @@ if ($user_level == 0) //Checks to see if user has logged in
 if (!get_settings('use_fileupload')) //Checks if file upload is enabled in the config
 	die (__("The admin disabled this function"));
 
+if ( !get_settings('fileupload_minlevel') )
+	die (__("You are not allowed to upload files"));
+
 $allowed_types = explode(' ', trim(strtolower(get_settings('fileupload_allowedtypes'))));
 
 if ($_POST['submit']) {
@@ -76,33 +79,28 @@ case '':
 </div><?php 
 break;
 case 'upload':
-?>
 
-<?php //Makes sure they choose a file
+	$imgalt = basename( (isset($_POST['imgalt'])) ? $_POST['imgalt'] : '' );
 
-//print_r($HTTP_POST_FILES);
-//die();
+	$img1_name = (strlen($imgalt)) ? $imgalt : basename( $_FILES['img1']['name'] );
+	$img1_name = preg_replace('/[^a-z0-9_.]/i', '', $img1_name); 
+	$img1_size = $_POST['img1_size'] ? intval($_POST['img1_size']) : intval($_FILES['img1']['size']);
 
+	$img1_type = (strlen($imgalt)) ? $_POST['img1_type'] : $_FILES['img1']['type'];
+	$imgdesc = htmlentities2($_POST['imgdesc']);
 
-    $imgalt = (isset($_POST['imgalt'])) ? $_POST['imgalt'] : $imgalt;
+	$pi = pathinfo($img1_name);
+	$imgtype = strtolower($pi['extension']);
 
-    $img1_name = (strlen($imgalt)) ? $_POST['imgalt'] : $HTTP_POST_FILES['img1']['name'];
-    $img1_type = (strlen($imgalt)) ? $_POST['img1_type'] : $HTTP_POST_FILES['img1']['type'];
-    $imgdesc = str_replace('"', '&amp;quot;', $_POST['imgdesc']);
-
-    $imgtype = explode(".",$img1_name);
-    $imgtype = strtolower($imgtype[count($imgtype)-1]);
-
-    if (in_array($imgtype, $allowed_types) == false) {
-        die(sprintf(__('File %1$s of type %2$s is not allowed.') , $img1_name, $imgtype));
-    }
+	if (in_array($imgtype, $allowed_types) == false)
+		die(sprintf(__('File %1$s of type %2$s is not allowed.') , $img1_name, $imgtype));
 
     if (strlen($imgalt)) {
         $pathtofile = get_settings('fileupload_realpath')."/".$imgalt;
         $img1 = $_POST['img1'];
     } else {
         $pathtofile = get_settings('fileupload_realpath')."/".$img1_name;
-        $img1 = $HTTP_POST_FILES['img1']['tmp_name'];
+        $img1 = $_FILES['img1']['tmp_name'];
     }
 
     // makes sure not to upload duplicates, rename duplicates
@@ -111,8 +109,8 @@ case 'upload':
     $tmppathtofile = $pathtofile2;
     $img2_name = $img1_name;
 
-    while (file_exists($pathtofile2)) {
-        $pos = strpos($tmppathtofile, '.'.trim($imgtype));
+    while ( file_exists($pathtofile2) ) {
+        $pos = strpos( strtolower($tmppathtofile), '.' . trim($imgtype) );
         $pathtofile_start = substr($tmppathtofile, 0, $pos);
         $pathtofile2 = $pathtofile_start.'_'.zeroise($i++, 2).'.'.trim($imgtype);
         $img2_name = explode('/', $pathtofile2);
@@ -158,6 +156,7 @@ case 'upload':
     </form>
 </div>
 <?php 
+
 require('admin-footer.php');
 die();
 
@@ -171,7 +170,7 @@ die();
             $moved = copy($img1, $pathtofile);
         }
         // Still couldn't get it. Give up.
-        if (!moved) {
+        if (!$moved) {
             die(sprintf(__("Couldn't upload your file to %s."), $pathtofile));
         } else {
 			chmod($pathtofile, 0666);
@@ -191,7 +190,7 @@ die();
             $max_side = 400;
         }
         elseif($_POST['thumbsize'] == 'custom') {
-            $max_side = $_POST['imgthumbsizecustom'];
+            $max_side = intval($_POST['imgthumbsizecustom']);
         }
         
         $result = wp_create_thumbnail($pathtofile, $max_side, NULL);
@@ -200,14 +199,12 @@ die();
         }
     }
 
+if ( ereg('image/',$img1_type) )
+	$piece_of_code = "<img src='" . get_settings('fileupload_url') ."/$img1_name' alt='$imgdesc' />";
+else
+	$piece_of_code = "<a href='". get_settings('fileupload_url') . "/$img1_name' title='$imgdesc'>$imgdesc</a>";
 
-
-if ( ereg('image/',$img1_type)) {
-    $piece_of_code = "&lt;img src=&quot;". get_settings('fileupload_url') ."/$img1_name&quot; alt=&quot;$imgdesc&quot; /&gt;";
-} else {
-    $piece_of_code = "&lt;a href=&quot;". get_settings('fileupload_url') . "/$img1_name&quot; title=&quot;$imgdesc&quot; /&gt;$imgdesc&lt;/a&gt;";
-};
-
+$piece_of_code = htmlspecialchars( $piece_of_code );
 ?>
 
 <h3><?php _e('File uploaded!') ?></h3>
@@ -230,4 +227,4 @@ Name:
 break;
 }
 include('admin-footer.php');
-?>
+?>
\ No newline at end of file
